"use strict";
/**
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.discardUrimap = exports.discardTransaction = exports.discardProgram = void 0;
const imperative_1 = require("@zowe/imperative");
const rest_1 = require("../../rest");
const constants_1 = require("../../constants");
/**
 * Discard a program installed in CICS through CMCI REST API
 * @param {AbstractSession} session - the session to connect to CMCI with
 * @param {IProgramParms} parms - parameters for discarding your program
 * @returns {Promise<ICMCIApiResponse>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} CICS program name not defined or blank
 * @throws {ImperativeError} CICS region name not defined or blank
 * @throws {ImperativeError} CicsCmciRestClient request fails
 */
async function discardProgram(session, parms) {
    imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.name, "CICS Program name", "CICS program name is required");
    imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.regionName, "CICS Region name", "CICS region name is required");
    imperative_1.Logger.getAppLogger().debug("Attempting to discard a program with the following parameters:\n%s", JSON.stringify(parms));
    const cicsPlex = parms.cicsPlex == null ? "" : parms.cicsPlex + "/";
    const cmciResource = "/" +
        constants_1.CicsCmciConstants.CICS_SYSTEM_MANAGEMENT +
        "/" +
        constants_1.CicsCmciConstants.CICS_PROGRAM_RESOURCE +
        "/" +
        cicsPlex +
        parms.regionName +
        "?CRITERIA=(PROGRAM=" +
        parms.name +
        ")";
    return rest_1.CicsCmciRestClient.deleteExpectParsedXml(session, cmciResource, []);
}
exports.discardProgram = discardProgram;
/**
 * Discard a transaction installed in CICS through CMCI REST API
 * @param {AbstractSession} session - the session to connect to CMCI with
 * @param {ITransactionParms} parms - parameters for discarding your transaction
 * @returns {Promise<ICMCIApiResponse>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} CICS transaction name not defined or blank
 * @throws {ImperativeError} CICS region name not defined or blank
 * @throws {ImperativeError} CicsCmciRestClient request fails
 */
async function discardTransaction(session, parms) {
    imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.name, "CICS Transaction name", "CICS transaction name is required");
    imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.regionName, "CICS Region name", "CICS region name is required");
    imperative_1.Logger.getAppLogger().debug("Attempting to discard a transaction with the following parameters:\n%s", JSON.stringify(parms));
    const cicsPlex = parms.cicsPlex == null ? "" : parms.cicsPlex + "/";
    const cmciResource = "/" +
        constants_1.CicsCmciConstants.CICS_SYSTEM_MANAGEMENT +
        "/" +
        constants_1.CicsCmciConstants.CICS_LOCAL_TRANSACTION +
        "/" +
        cicsPlex +
        parms.regionName +
        "?CRITERIA=(TRANID=" +
        parms.name +
        ")";
    return rest_1.CicsCmciRestClient.deleteExpectParsedXml(session, cmciResource, []);
}
exports.discardTransaction = discardTransaction;
async function discardUrimap(session, parms) {
    imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.name, "CICS URIMap name", "CICS URIMap name is required");
    imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.regionName, "CICS Region name", "CICS region name is required");
    imperative_1.Logger.getAppLogger().debug("Attempting to discard a URIMap with the following parameters:\n%s", JSON.stringify(parms));
    const cicsPlex = parms.cicsPlex == null ? "" : parms.cicsPlex + "/";
    const cmciResource = "/" +
        constants_1.CicsCmciConstants.CICS_SYSTEM_MANAGEMENT +
        "/" +
        constants_1.CicsCmciConstants.CICS_URIMAP +
        "/" +
        cicsPlex +
        `${parms.regionName}?CRITERIA=(NAME='${parms.name}')`;
    return rest_1.CicsCmciRestClient.deleteExpectParsedXml(session, cmciResource, []);
}
exports.discardUrimap = discardUrimap;
//# sourceMappingURL=Discard.js.map